package com.example.hangry;

import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.stereotype.Repository;

import java.util.List;

@Repository
public interface IngredientRepository extends JpaRepository<Ingredient, Long> {

    // 1. Alle globalen Zutaten abrufen
    List<Ingredient> findByIsGlobal(boolean isGlobal);

    // 2. Zutaten, die einem bestimmten Benutzer gehören, abrufen
    List<Ingredient> findByUserId(Long userId);

    // 3. Zutaten suchen, die global und/oder benutzerdefiniert nach Name passen
    List<Ingredient> findByNameContainingIgnoreCase(String name);

    // 4. Benutzerdefinierte Zutat für einen bestimmten Benutzer nach Namen abrufen
    List<Ingredient> findByNameAndUserId(String name, Long userId);

    // 5. Überprüfen, ob eine Zutat global existiert
    boolean existsByNameAndIsGlobal(String name, boolean isGlobal);
}

